Struct DeviceFlags
pub struct DeviceFlags(<DeviceFlags as PublicFlags>::Internal);Expand description
Bit vector of property flags.
Tuple Fields
0: <DeviceFlags as PublicFlags>::InternalImplementations
impl DeviceFlags
impl DeviceFlags
pub const SEEN_GPS: Self
pub const SEEN_GPS: Self
GPS data has been seen on this device.
pub const SEEN_RTCM2: Self
pub const SEEN_RTCM2: Self
RTCM2 data has been seen on this device.
pub const SEEN_RTCM3: Self
pub const SEEN_RTCM3: Self
RTCM3 data has been seen on this device.
pub const SEEN_AIS: Self
pub const SEEN_AIS: Self
AIS data has been seen on this device.
impl DeviceFlags
impl DeviceFlags
pub const fn empty() -> Self
pub const fn empty() -> Self
Get a flags value with all bits unset.
pub const fn all() -> Self
pub const fn all() -> Self
Get a flags value with all known bits set.
pub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: Self)
pub fn insert(&mut self, other: Self)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
impl DeviceFlags
impl DeviceFlags
pub const fn iter(&self) -> Iter<DeviceFlags> ⓘ
pub const fn iter(&self) -> Iter<DeviceFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<DeviceFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<DeviceFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.